# pyp333
a test for pypi package
being inspired by https://github.com/ytakefuji/defense
The goal of this is  compareing the diferense of Military spending　and gdp of us,uk,russia,ukraine on graph.
 using SIPRI dataset https://sipri.org/sites/default/files/SIPRI-Milex-data-1949-2020_0.xlsx  
 i 　visualize the data of total cost,per cost and gdp
 
how to install :
pip install pyp333
